#' @import statgenGWAS
#'
#' @keywords internal
"_PACKAGE"

#' @importFrom rlang .data
NULL

## CRAN Note avoidance.
if (getRversion() >= "2.15.1") {
  utils::globalVariables("i")
}
